summaryrefslogtreecommitdiffstats
path: root/kspread/kspread_cell.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/kspread_cell.cc')
-rw-r--r--kspread/kspread_cell.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kspread/kspread_cell.cc b/kspread/kspread_cell.cc
index 7e2d85cd..d8799d9f 100644
--- a/kspread/kspread_cell.cc
+++ b/kspread/kspread_cell.cc
@@ -404,7 +404,7 @@ TQString Cell::columnName() const
return columnName( d->column );
}
-KLocale* Cell::locale() const
+TDELocale* Cell::locale() const
{
return d->format->sheet()->doc()->locale();
}
@@ -6814,9 +6814,9 @@ bool Cell::loadCellData(const TQDomElement & text, Paste::Operation op )
kdWarning(36001) << "Couldn't parse '" << t << "' as number." << endl;
}
/* We will need to localize the text version of the number */
- KLocale* locale = format()->sheet()->doc()->locale();
+ TDELocale* locale = format()->sheet()->doc()->locale();
- /* KLocale::formatNumber requires the precision we want to return.
+ /* TDELocale::formatNumber requires the precision we want to return.
*/
int precision = t.length() - t.find('.') - 1;